@@ -3,21 +3,16 @@ use strict;
 use warnings;
 
 BEGIN {
-    use base qw/Mango::Catalyst::Controller::Form/;
+    use base qw/Mango::Catalyst::Controller/;
     use Mango ();
     use Path::Class ();
-    
-    __PACKAGE__->form_directory(
-        Path::Class::Dir->new(Mango->share, 'forms', 'admin', 'roles')
+
+    __PACKAGE__->config(
+        resource_name  => 'admin/roles',
+        form_directory => Path::Class::Dir->new(Mango->share, 'forms', 'admin', 'roles')
     );
 };
 
-sub _parse_PathPrefix_attr {
-    my ($self, $c, $name, $value) = @_;
-
-    return PathPart => $self->path_prefix;
-};
-
 sub index : Template('admin/roles/index') {
     my ($self, $c) = @_;
     my $page = $c->request->param('page') || 1;
@@ -60,7 +55,7 @@ sub create : Local Template('admin/roles/create') {
         });
 
         $c->response->redirect(
-            $c->uri_for('/', $self->path_prefix, $role->id, 'edit/')
+            $c->uri_for($self->action_for('edit'), [$role->id]) . '/'
         );
     };
 };
@@ -74,12 +69,17 @@ sub edit : Chained('load') PathPart Args(0) Template('admin/roles/edit') {
         id          => $role->id,
         name        => $role->name,
         description => $role->description,
-        created     => $role->created . ''
+        created     => $role->created . '',
+        updated     => $role->updated . ''
     });
 
     if ($self->submitted && $self->validate->success) {
         $role->description($form->field('description'));
         $role->update;
+
+        $form->values({
+            updated     => $role->updated . ''
+        });
     };
 };
 
@@ -94,7 +94,7 @@ sub delete : Chained('load') PathPart Args(0) Template('admin/roles/delete') {
             $role->destroy;
 
             $c->response->redirect(
-                $c->uri_for('/', $self->path_prefix . '/')
+                $c->uri_for($self->action_for('index')) . '/'
             );
         } else {
             $c->stash->{'errors'} = ['ID_MISTMATCH'];
